"use client";

import Image from "next/image";

import { motion } from "framer-motion";
import { ArrowDown } from "lucide-react";

import { Button } from "@/components/ui/button";
import { cn } from "@/lib/utils";
import { ProductDetailsBlogInfo } from "@/utils/get-fake-data";

import { TipCard } from "./tip-card";

interface ProductDetailsBlogInfoCardProps {
	info: ProductDetailsBlogInfo;
	locale: string;
}

export function ProductDetailsBlogInfoCard({
	info,
	locale,
}: ProductDetailsBlogInfoCardProps) {
	const isRTL = locale === "ar";
	const contentOrder =
		info.imagePosition === "right"
			? "order-first"
			: "order-last lg:order-first";
	const imageOrder =
		info.imagePosition === "right" ? "order-last" : "order-first lg:order-last";

	return (
		<section className="w-full overflow-hidden bg-white py-16">
			<div className="container mx-auto max-w-7xl px-4">
				<div className="grid items-center gap-8 lg:grid-cols-[1fr,1.5fr] lg:gap-12">
					{/* Content */}
					<motion.div
						initial={{
							opacity: 0,
							x: info.imagePosition === "right" ? -50 : 50,
						}}
						whileInView={{ opacity: 1, x: 0 }}
						viewport={{ once: true }}
						transition={{ duration: 0.5 }}
						className={cn(
							"flex flex-col space-y-6",
							contentOrder,
							isRTL ? "text-right" : "text-left"
						)}
					>
						<p
							className={cn(
								"text-3xl tracking-tight text-[#1E1E1E] sm:text-4xl lg:text-4xl",
								isRTL && "font-arabic"
							)}
						>
							{info.title?.[locale]}
						</p>
						<p
							className={cn(
								"text-base text-gray-600 sm:text-lg",
								isRTL && "font-arabic"
							)}
						>
							{info.description?.[locale]}
						</p>
						<div>
							<Button className="mt-6 rounded-xl bg-custom-primary-accent px-6 py-4 text-white hover:bg-custom-primary">
								{locale === "ar" ? "أكتشف المزيد " : "Discover more"}
								<ArrowDown className="h-6 w-6" />
							</Button>
						</div>
					</motion.div>

					{/* Image Container */}
					<motion.div
						initial={{
							opacity: 0,
							x: info.imagePosition === "right" ? 50 : -50,
						}}
						whileInView={{ opacity: 1, x: 0 }}
						viewport={{ once: true }}
						transition={{ duration: 0.5 }}
						className={cn(
							"relative aspect-[16/9] w-full overflow-hidden lg:aspect-[21/9]",
							imageOrder
						)}
					>
						<div className="relative h-full w-full">
							<Image
								src={info.image}
								alt={info.title?.[locale]}
								fill
								className="rounded-lg object-cover transition-transform duration-300 hover:scale-105"
								sizes="(max-width: 768px) 100vw, (max-width: 1200px) 60vw, 1000px"
							/>
							<div className="absolute inset-0 rounded-lg bg-gradient-to-t from-black/20 to-transparent" />

							{/* Tip Card with proper positioning */}
							<div className="absolute -bottom-8 right-8 z-[100] max-w-[300px]">
								<TipCard
									icon={info.tipIcon}
									title={info.tipTitle?.[locale]}
									description={info.tipDescription?.[locale]}
								/>
							</div>
						</div>
					</motion.div>
				</div>
			</div>
		</section>
	);
}
